If you are interested in this panel, please let me know, so I will invest more time in it. Bug reports, feature requests and suggestions are welcome.
[See previews](../../wiki/Previews).

![](../../wiki/screenshot.png)
